package sun.security.provider.certpath;

import sun.security.util.UntrustedCertificates;
import java.security.cert.X509Certificate;
import java.util.Collection;
import java.security.cert.Certificate;
import java.util.Set;
import java.security.cert.CertPathValidatorException;
import sun.security.util.Debug;
import java.security.cert.PKIXCertPathChecker;

public final class UntrustedChecker extends PKIXCertPathChecker
{
    private static final Debug debug;
    
    public UntrustedChecker() {
    }
    
    @Override
    public void init(boolean b) throws CertPathValidatorException {
    }
    
    @Override
    public boolean isForwardCheckingSupported() {
        return true;
    }
    
    @Override
    public Set<String> getSupportedExtensions() {
        return null;
    }
    
    @Override
    public void check(Certificate certificate, Collection<String> collection) throws CertPathValidatorException {
        X509Certificate cert = (X509Certificate)certificate;
        if (UntrustedCertificates.isUntrusted(cert)) {
            if (UntrustedChecker.debug != null) {
                UntrustedChecker.debug.println("UntrustedChecker: untrusted certificate " + cert.getSubjectX500Principal());
            }
            throw new CertPathValidatorException("Untrusted certificate: " + cert.getSubjectX500Principal());
        }
        else {
            return;
        }
    }
    
    static {
        debug = Debug.getInstance("certpath");
    }
}
